pub struct SpecData<S> {Show 13 fields
pub summary: S,
pub description: S,
pub availability: S,
pub license_details: S,
pub repo_url: Option<S>,
pub home_url: Option<S>,
pub docs_url: Option<S>,
pub input_params_url: Option<S>,
pub examples_url: Option<S>,
pub paper_url: Option<S>,
pub license: License,
pub license_url: Option<S>,
pub tested: bool,
}Expand description
Tool-specific descriptive data which does not depend on a UI framework or
execution environment or on the tool’s identity (slug/name), so that the
same field list can also back the catalog’s &'static str-based static
data – see tool_definitions::catalog::CatalogEntry::spec.
Fields
summary: STerser than Summary. May also include copy+paste+modify from an tool-official source.
description: SNote: This may be taken directly (Copy + paste, or modified) directly from the tool’s official website, docs, or paper. It may include a degree of marketing copy, but we try to make it descriptive if that’s too heavy.
availability: Slicense_details: Srepo_url: Option<S>home_url: Option<S>docs_url: Option<S>input_params_url: Option<S>Documentation for the tool’s input parameters.
examples_url: Option<S>Official examples of use
paper_url: Option<S>license: Licenselicense_url: Option<S>A tool-specific license page, used when license is
License::Other (or any other variant without a fixed
License::official_url).
tested: boolTested, compared inputs and outputs against official docs if available, and had results evaluated in at least some cases, e.g. official examples.